.. include:: ../README.rst

.. admonition:: Why naive?

    The W3C XML Schema offers so much flexibility and abstraction layers and grammatical rules to support practically any xml document definition.

    Integration teams and clients don't care about any of that, take out abstraction and flexibility and you are left with lean named data structures with typed attributes and a namespace for humans to read!


.. toctree::
    :maxdepth: 1

    installation
    codegen
    architecture
    dataclasses
    plantuml
    demos
    changelog
    about
    api
